==> v20.10.9.zip: drone-docker-buildx/cmd/drone-docker-buildx/config.go <==
package main

import (
	"github.com/thegeeklab/drone-docker-buildx/plugin"
	"github.com/urfave/cli/v2"
)

// settingsFlags has the cli.Flags for the plugin.Settings.
func settingsFlags(settings *plugin.Settings) []cli.Flag {
	return []cli.Flag{
		&cli.BoolFlag{
			Name:        "dry-run",
			Usage:       "dry run disables docker push",
			EnvVars:     []string{"PLUGIN_DRY_RUN"},
			Destination: &settings.Dryrun,
		},
		&cli.StringFlag{
			Name:        "remote.url",
			Usage:       "git remote url",
			EnvVars:     []string{"DRONE_REMOTE_URL"},
			Destination: &settings.Build.Remote,
		},
		&cli.StringFlag{
			Name:        "daemon.mirror",
			Usage:       "docker daemon registry mirror",
			EnvVars:     []string{"PLUGIN_MIRROR", "DOCKER_PLUGIN_MIRROR"},
			Destination: &settings.Daemon.Mirror,
		},
		&cli.StringFlag{
			Name:        "daemon.storage-driver",
			Usage:       "docker daemon storage driver",
			EnvVars:     []string{"PLUGIN_STORAGE_DRIVER"},
			Destination: &settings.Daemon.StorageDriver,
		},
		&cli.StringFlag{
			Name:        "daemon.storage-path",
			Usage:       "docker daemon storage path",
			Value:       "/var/lib/docker",
			EnvVars:     []string{"PLUGIN_STORAGE_PATH"},
			Destination: &settings.Daemon.StoragePath,
		},
		&cli.StringFlag{
			Name:        "daemon.bip",
			Usage:       "docker daemon bride ip address",
			EnvVars:     []string{"PLUGIN_BIP"},
			Destination: &settings.Daemon.Bip,
		},
		&cli.StringFlag{
			Name:        "daemon.mtu",
			Usage:       "docker daemon custom mtu setting",
			EnvVars:     []string{"PLUGIN_MTU"},
			Destination: &settings.Daemon.MTU,
		},
		&cli.StringSliceFlag{
			Name:        "daemon.dns",
			Usage:       "docker daemon dns server",
			EnvVars:     []string{"PLUGIN_CUSTOM_DNS"},
			Destination: &settings.Daemon.DNS,
		},
		&cli.StringSliceFlag{
			Name:        "daemon.dns-search",
			Usage:       "docker daemon dns search domains",
			EnvVars:     []string{"PLUGIN_CUSTOM_DNS_SEARCH"},
			Destination: &settings.Daemon.DNSSearch,
		},
		&cli.BoolFlag{
			Name:        "daemon.insecure",
			Usage:       "docker daemon allows insecure registries",
			EnvVars:     []string{"PLUGIN_INSECURE"},
			Destination: &settings.Daemon.Insecure,
		},
		&cli.BoolFlag{
			Name:        "daemon.ipv6",
			Usage:       "docker daemon IPv6 networking",
			EnvVars:     []string{"PLUGIN_IPV6"},
			Destination: &settings.Daemon.IPv6,
		},
		&cli.BoolFlag{
			Name:        "daemon.experimental",
			Usage:       "docker daemon Experimental mode",
			EnvVars:     []string{"PLUGIN_EXPERIMENTAL"},
			Destination: &settings.Daemon.Experimental,
		},
		&cli.BoolFlag{
			Name:        "daemon.debug",
			Usage:       "docker daemon executes in debug mode",
			EnvVars:     []string{"PLUGIN_DEBUG", "DOCKER_LAUNCH_DEBUG"},
			Destination: &settings.Daemon.Debug,
		},
		&cli.BoolFlag{
			Name:        "daemon.off",
			Usage:       "don't start the docker daemon",
			EnvVars:     []string{"PLUGIN_DAEMON_OFF"},
			Destination: &settings.Daemon.Disabled,
		},
		&cli.StringFlag{
			Name:        "daemon.buildkit-config",
			Usage:       "location of buildkit config file",
			EnvVars:     []string{"PLUGIN_BUILDKIT_CONFIG"},
			Destination: &settings.Daemon.BuildkitConfig,
		},
		&cli.StringFlag{
			Name:        "dockerfile",
			Usage:       "build dockerfile",
			Value:       "Dockerfile",
			EnvVars:     []string{"PLUGIN_DOCKERFILE"},
			Destination: &settings.Build.Dockerfile,
		},
		&cli.StringFlag{
			Name:        "context",
			Usage:       "build context",
			Value:       ".",
			EnvVars:     []string{"PLUGIN_CONTEXT"},
			Destination: &settings.Build.Context,
		},
		&cli.StringSliceFlag{
			Name:        "tags",
			Usage:       "build tags",
			Value:       cli.NewStringSlice([]string{"latest"}...),
			EnvVars:     []string{"PLUGIN_TAG", "PLUGIN_TAGS"},
			FilePath:    ".tags",
			Destination: &settings.Build.Tags,
		},
		&cli.BoolFlag{
			Name:        "tags.auto",
			Usage:       "default build tags",
			EnvVars:     []string{"PLUGIN_DEFAULT_TAGS", "PLUGIN_AUTO_TAG"},
			Destination: &settings.Build.TagsAuto,
		},
		&cli.StringFlag{
			Name:        "tags.suffix",
			Usage:       "default build tags with suffix",
			EnvVars:     []string{"PLUGIN_DEFAULT_SUFFIX", "PLUGIN_AUTO_TAG_SUFFIX"},
			Destination: &settings.Build.TagsSuffix,
		},
		&cli.StringSliceFlag{
			Name:        "args",
			Usage:       "build args",
			EnvVars:     []string{"PLUGIN_BUILD_ARGS"},
			Destination: &settings.Build.Args,
		},
		&cli.StringSliceFlag{
			Name:        "args-from-env",
			Usage:       "build args",
			EnvVars:     []string{"PLUGIN_BUILD_ARGS_FROM_ENV"},
			Destination: &settings.Build.ArgsEnv,
		},
		&cli.BoolFlag{
			Name:        "quiet",
			Usage:       "quiet docker build",
			EnvVars:     []string{"PLUGIN_QUIET"},
			Destination: &settings.Build.Quiet,
		},
		&cli.StringFlag{
			Name:        "target",
			Usage:       "build target",
			EnvVars:     []string{"PLUGIN_TARGET"},
			Destination: &settings.Build.Target,
		},
		&cli.StringSliceFlag{
			Name:        "cache-from",
			Usage:       "images to consider as cache sources",
			EnvVars:     []string{"PLUGIN_CACHE_FROM"},
			Destination: &settings.Build.CacheFrom,
		},
		&cli.BoolFlag{
			Name:        "squash",
			Usage:       "squash the layers at build time",
			EnvVars:     []string{"PLUGIN_SQUASH"},
			Destination: &settings.Build.Squash,
		},
		&cli.BoolFlag{
			Name:        "pull-image",
			Usage:       "force pull base image at build time",
			EnvVars:     []string{"PLUGIN_PULL_IMAGE"},
			Value:       true,
			Destination: &settings.Build.Pull,
		},
		&cli.BoolFlag{
			Name:        "compress",
			Usage:       "compress the build context using gzip",
			EnvVars:     []string{"PLUGIN_COMPRESS"},
			Destination: &settings.Build.Compress,
		},
		&cli.StringFlag{
			Name:        "repo",
			Usage:       "docker repository",
			EnvVars:     []string{"PLUGIN_REPO"},
			Destination: &settings.Build.Repo,
		},
		&cli.StringFlag{
			Name:        "docker.registry",
			Usage:       "docker registry",
			Value:       "https://index.docker.io/v1/",
			EnvVars:     []string{"PLUGIN_REGISTRY", "DOCKER_REGISTRY"},
			Destination: &settings.Login.Registry,
		},
		&cli.StringFlag{
			Name:        "docker.username",
			Usage:       "docker username",
			EnvVars:     []string{"PLUGIN_USERNAME", "DOCKER_USERNAME"},
			Destination: &settings.Login.Username,
		},
		&cli.StringFlag{
			Name:        "docker.password",
			Usage:       "docker password",
			EnvVars:     []string{"PLUGIN_PASSWORD", "DOCKER_PASSWORD"},
			Destination: &settings.Login.Password,
		},
		&cli.StringFlag{
			Name:        "docker.email",
			Usage:       "docker email",
			EnvVars:     []string{"PLUGIN_EMAIL", "DOCKER_EMAIL"},
			Destination: &settings.Login.Email,
		},
		&cli.StringFlag{
			Name:        "docker.config",
			Usage:       "docker json dockerconfig content",
			EnvVars:     []string{"PLUGIN_CONFIG", "DOCKER_PLUGIN_CONFIG"},
			Destination: &settings.Login.Config,
		},
		&cli.BoolFlag{
			Name:        "docker.purge",
			Usage:       "docker should cleanup images",
			EnvVars:     []string{"PLUGIN_PURGE"},
			Value:       true,
			Destination: &settings.Cleanup,
		},
		&cli.BoolFlag{
			Name:        "no-cache",
			Usage:       "do not use cached intermediate containers",
			EnvVars:     []string{"PLUGIN_NO_CACHE"},
			Destination: &settings.Build.NoCache,
		},
		&cli.StringSliceFlag{
			Name:        "add-host",
			Usage:       "additional host:IP mapping",
			EnvVars:     []string{"PLUGIN_ADD_HOST"},
			Destination: &settings.Build.AddHost,
		},
		&cli.StringSliceFlag{
			Name:        "platforms",
			Usage:       "arget platform for build",
			EnvVars:     []string{"PLUGIN_PLATFORMS"},
			Destination: &settings.Build.Platforms,
		},
	}
}

==> v20.12.1.zip: drone-docker-buildx/cmd/drone-docker-buildx/config.go <==
package main

import (
	"github.com/thegeeklab/drone-docker-buildx/plugin"
	"github.com/urfave/cli/v2"
)

// settingsFlags has the cli.Flags for the plugin.Settings.
func settingsFlags(settings *plugin.Settings, category string) []cli.Flag {
	return []cli.Flag{
		&cli.BoolFlag{
			Name:        "dry-run",
			EnvVars:     []string{"PLUGIN_DRY_RUN"},
			Usage:       "disable docker push",
			Destination: &settings.Dryrun,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "daemon.mirror",
			EnvVars:     []string{"PLUGIN_MIRROR", "DOCKER_PLUGIN_MIRROR"},
			Usage:       "registry mirror to pull images",
			Destination: &settings.Daemon.Mirror,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "daemon.storage-driver",
			EnvVars:     []string{"PLUGIN_STORAGE_DRIVER"},
			Usage:       "docker daemon storage driver",
			Destination: &settings.Daemon.StorageDriver,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "daemon.storage-path",
			EnvVars:     []string{"PLUGIN_STORAGE_PATH"},
			Usage:       "docker daemon storage path",
			Value:       "/var/lib/docker",
			Destination: &settings.Daemon.StoragePath,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "daemon.bip",
			EnvVars:     []string{"PLUGIN_BIP"},
			Usage:       "allow the docker daemon to bride ip address",
			Destination: &settings.Daemon.Bip,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "daemon.mtu",
			EnvVars:     []string{"PLUGIN_MTU"},
			Usage:       "docker daemon custom mtu setting",
			Destination: &settings.Daemon.MTU,
			Category:    category,
		},
		&cli.StringSliceFlag{
			Name:        "daemon.dns",
			EnvVars:     []string{"PLUGIN_CUSTOM_DNS"},
			Usage:       "custom docker daemon dns server",
			Destination: &settings.Daemon.DNS,
			Category:    category,
		},
		&cli.StringSliceFlag{
			Name:        "daemon.dns-search",
			EnvVars:     []string{"PLUGIN_CUSTOM_DNS_SEARCH"},
			Usage:       "custom docker daemon dns search domain",
			Destination: &settings.Daemon.DNSSearch,
			Category:    category,
		},
		&cli.BoolFlag{
			Name:        "daemon.insecure",
			EnvVars:     []string{"PLUGIN_INSECURE"},
			Usage:       "allow the docker daemon to use insecure registries",
			Value:       false,
			Destination: &settings.Daemon.Insecure,
			Category:    category,
		},
		&cli.BoolFlag{
			Name:        "daemon.ipv6",
			EnvVars:     []string{"PLUGIN_IPV6"},
			Usage:       "enable docker daemon IPv6 support",
			Value:       false,
			Destination: &settings.Daemon.IPv6,
			Category:    category,
		},
		&cli.BoolFlag{
			Name:        "daemon.experimental",
			EnvVars:     []string{"PLUGIN_EXPERIMENTAL"},
			Usage:       "enable docker daemon experimental mode",
			Value:       false,
			Destination: &settings.Daemon.Experimental,
			Category:    category,
		},
		&cli.BoolFlag{
			Name:        "daemon.debug",
			EnvVars:     []string{"PLUGIN_DEBUG"},
			Usage:       "enable verbose debug mode for the docker daemon",
			Value:       false,
			Destination: &settings.Daemon.Debug,
			Category:    category,
		},
		&cli.BoolFlag{
			Name:        "daemon.off",
			EnvVars:     []string{"PLUGIN_DAEMON_OFF"},
			Usage:       "disable the startup of the docker daemon",
			Value:       false,
			Destination: &settings.Daemon.Disabled,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "daemon.buildkit-config",
			EnvVars:     []string{"PLUGIN_BUILDKIT_CONFIG"},
			Usage:       "content of the docker buildkit json config",
			Destination: &settings.Daemon.BuildkitConfig,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "dockerfile",
			EnvVars:     []string{"PLUGIN_DOCKERFILE"},
			Usage:       "dockerfile to use for the image build",
			Value:       "Dockerfile",
			Destination: &settings.Build.Dockerfile,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "context",
			EnvVars:     []string{"PLUGIN_CONTEXT"},
			Usage:       "path of the build context",
			Value:       ".",
			Destination: &settings.Build.Context,
			Category:    category,
		},
		&cli.StringSliceFlag{
			Name:        "named-context",
			EnvVars:     []string{"PLUGIN_NAMED_CONTEXT"},
			Usage:       "additional named build context",
			Destination: &settings.Build.NamedContext,
			Category:    category,
		},
		&cli.StringSliceFlag{
			Name:        "tags",
			EnvVars:     []string{"PLUGIN_TAG", "PLUGIN_TAGS"},
			Usage:       "repository tags to use for the image",
			FilePath:    ".tags",
			Destination: &settings.Build.Tags,
			Category:    category,
		},
		&cli.BoolFlag{
			Name:        "tags.auto",
			EnvVars:     []string{"PLUGIN_DEFAULT_TAGS", "PLUGIN_AUTO_TAG"},
			Usage:       "generate tag names automatically based on git branch and git tag",
			Value:       false,
			Destination: &settings.Build.TagsAuto,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "tags.suffix",
			EnvVars:     []string{"PLUGIN_DEFAULT_SUFFIX", "PLUGIN_AUTO_TAG_SUFFIX"},
			Usage:       "generate tag names with the given suffix",
			Destination: &settings.Build.TagsSuffix,
			Category:    category,
		},
		&cli.StringSliceFlag{
			Name:        "args",
			EnvVars:     []string{"PLUGIN_BUILD_ARGS"},
			Usage:       "custom build arguments for the build",
			Destination: &settings.Build.Args,
			Category:    category,
		},
		&cli.StringSliceFlag{
			Name:        "args-from-env",
			EnvVars:     []string{"PLUGIN_BUILD_ARGS_FROM_ENV"},
			Usage:       "forward environment variables as custom arguments to the build",
			Destination: &settings.Build.ArgsEnv,
			Category:    category,
		},
		&cli.BoolFlag{
			Name:        "quiet",
			EnvVars:     []string{"PLUGIN_QUIET"},
			Usage:       "enable suppression of the build output",
			Value:       false,
			Destination: &settings.Build.Quiet,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "output",
			EnvVars:     []string{"PLUGIN_OUTPUT"},
			Usage:       "export action for the build result",
			Destination: &settings.Build.Output,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "target",
			EnvVars:     []string{"PLUGIN_TARGET"},
			Usage:       "build target to use",
			Destination: &settings.Build.Target,
			Category:    category,
		},
		&cli.StringSliceFlag{
			Name:        "cache-from",
			EnvVars:     []string{"PLUGIN_CACHE_FROM"},
			Usage:       "images to consider as cache sources",
			Destination: &settings.Build.CacheFrom,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "cache-to",
			EnvVars:     []string{"PLUGIN_CACHE_TO"},
			Usage:       "cache destination for the build cache",
			Destination: &settings.Build.CacheTo,
			Category:    category,
		},
		&cli.BoolFlag{
			Name:        "pull-image",
			EnvVars:     []string{"PLUGIN_PULL_IMAGE"},
			Usage:       "enforce to pull base image at build time",
			Value:       true,
			Destination: &settings.Build.Pull,
			Category:    category,
		},
		&cli.BoolFlag{
			Name:        "compress",
			EnvVars:     []string{"PLUGIN_COMPRESS"},
			Usage:       "enable compression of the build context using gzip",
			Value:       false,
			Destination: &settings.Build.Compress,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "repo",
			EnvVars:     []string{"PLUGIN_REPO"},
			Usage:       "repository name for the image",
			Destination: &settings.Build.Repo,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "docker.registry",
			EnvVars:     []string{"PLUGIN_REGISTRY", "DOCKER_REGISTRY"},
			Usage:       "docker registry to authenticate with",
			Value:       "https://index.docker.io/v1/",
			Destination: &settings.Login.Registry,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "docker.username",
			EnvVars:     []string{"PLUGIN_USERNAME", "DOCKER_USERNAME"},
			Usage:       "username for registry authentication",
			Destination: &settings.Login.Username,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "docker.password",
			EnvVars:     []string{"PLUGIN_PASSWORD", "DOCKER_PASSWORD"},
			Usage:       "password for registry authentication",
			Destination: &settings.Login.Password,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "docker.email",
			EnvVars:     []string{"PLUGIN_EMAIL", "DOCKER_EMAIL"},
			Usage:       "email address for registry authentication",
			Destination: &settings.Login.Email,
			Category:    category,
		},
		&cli.StringFlag{
			Name:        "docker.config",
			EnvVars:     []string{"PLUGIN_CONFIG", "DOCKER_PLUGIN_CONFIG"},
			Usage:       "content of the docker daemon json config",
			Destination: &settings.Login.Config,
			Category:    category,
		},
		&cli.BoolFlag{
			Name:        "docker.purge",
			EnvVars:     []string{"PLUGIN_PURGE"},
			Usage:       "enable cleanup of the docker environment at the end of a build",
			Value:       true,
			Destination: &settings.Cleanup,
			Category:    category,
		},
		&cli.BoolFlag{
			Name:        "no-cache",
			EnvVars:     []string{"PLUGIN_NO_CACHE"},
			Usage:       "disable the usage of cached intermediate containers",
			Value:       false,
			Destination: &settings.Build.NoCache,
			Category:    category,
		},
		&cli.StringSliceFlag{
			Name:        "add-host",
			EnvVars:     []string{"PLUGIN_ADD_HOST"},
			Usage:       "additional host:ip mapping",
			Destination: &settings.Build.AddHost,
			Category:    category,
		},
		&cli.StringSliceFlag{
			Name:        "platforms",
			EnvVars:     []string{"PLUGIN_PLATFORMS"},
			Usage:       "target platform for build",
			Destination: &settings.Build.Platforms,
			Category:    category,
		},
	}
}
